Module confirm

Module confirm 

Generic yes/no confirmation dialog.

ConfirmDialog is a reusable two-button dialog that emits a caller-supplied DialogAction when the user confirms (y / Y / Enter) and closes without action on n / N / Esc. It is used by the root menu for the “Write profile” and “Read profile” rows (T15) and can be reused by any future flow that needs a single-shot confirmation prompt.

Structs

ConfirmDialog
Reusable yes/no confirmation dialog.